/* 
This program (formats_for_boat_detailed_file.sas) creates the formats
catalog for boat_detailed_file.sas7bdat.

Instructions for Windows users:

1. Create a folder for your files, e.g. c:\sasfiles
2. Place boat_detailed_file.sas7bdat and formats_for_boat_detailed_file.sas
   in the folder
3. Edit the libname statement in formats_for_boat_detailed_file.sas so that
   it refers to the folder, e.g.: libname library 'c:\sasfiles'
4. Open and run formats_for_boat_detailed_file.sas.  This will create
   the formats catalog, "formats.sas7bcat" in that folder.
5. You may now use boat_detailed_file.sas7bdat any way you
   like, for example the following program will create a frequency listing:

   libname library 'c:\sasfiles';
   proc freq data=library.boat_detailed_file; 
      tables _all_;
   run;

   Note that by using the name "library" for your libname when inputting the 
   data, SAS will automatically look in that same location for the formats
   catalog.  Otherwise, you would need to use a "fmtsearch" option to tell
   SAS where to look for the formats catalog.
*/

libname library '';

proc format library=library;

   value V00015F 
      1 = "01-A POWERBOAT,"
      2 = "02-A SAILBOAT"
      3 = "03-A PERSONAL WATERCRAFT SUCH AS A JET SKI"
      4 = "04-CANOE"
      5 = "05-KAYAK"
      6 = "06-SOMETHING ELSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00040F 
      1 = "01-YES"
      2 = "02-NO"
      88 = "88-INVALID RESPONSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED/MISSING"
   ;
   value PREF 
      1 = "01-ANSWER PROVIDED"
      99 = "99-MISSING"
   ;
   value HAPPF 
      1 = "01-I NEVER OWNED THAT BOAT"
      2 = "02-I SOLD OR GAVE AWAY THE BOAT"
      3 = "03-SOMETHING ELSE (PLEASE EXPLAIN)"
      88 = "88-INVALID RESPONSE"
      99 = "99-MISSING"
   ;
   value V00052F 
      1 = "01-YES"
      2 = "02-NO"
      88 = "88-INVALID RESPONSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED/MISSING"
   ;
   value V00054F 
      1 = "01-ALUMINUM"
      2 = "02-STEEL"
      3 = "03-CARBON FIBER"
      4 = "04-FIBERGLASS"
      5 = "05-RIGID HULL INFLATABLE"
      6 = "06-RUBBER"
      7 = "07-VINYL"
      8 = "08-CANVAS"
      9 = "09-WOOD"
      10 = "10-ANOTHER MATERIAL"
      11 = "11-PLASTIC (BACK-CODED)"
      88 = "88-INVALID RESPONSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED/MISSING"
   ;
   value M00159F 
      1 = "01-GAVE RESPONSE"
      88 = "88-INVALID RESPONSE"
      99 = "99-MISSING"
   ;
   value DKRF3F 
      997 = "997-DON'T KNOW"
      999 = "999-REFUSED"
   ;
   value DKRF4F 
      8888 = "8888-INVALID RESPONSE"
      9997 = "9997-DON'T KNOW"
      9999 = "9999-REFUSED/MISSING"
   ;
   value V00070F 
      1 = "01-YES"
      2 = "02-NO"
      88 = "88-INVALID RESPONSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED/MISSING"
   ;
   value V00079F 
      1 = "01-DIESEL"
      2 = "02-ELECTRIC"
      3 = "03-GASOLINE"
      4 = "04-ANOTHER TYPE OF FUEL"
      5 = "05-GAS/OIL MIXTURE (BACK-CODED)"
      88 = "88-INVALID RESPONSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED/MISSING"
   ;
   value MOTHPF 
      997 = "997-DON'T KNOW"
      998 = "998-MORE THAN 996 HORSEPOWER"
      999 = "999-REFUSED"
      8888 = "8888-INVALID RESPONSE"
      9999 = "9999-MISSING"
   ;
   value V00080F 
      1 = "01-ONE"
      2 = "02-TWO"
      3 = "03-THREE"
      4 = "04-FOUR"
      5 = "05-FIVE"
      6 = "06-SIX"
      7 = "07-SEVEN"
      8 = "08-EIGHT"
      88 = "88-INVALID RESPONSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED/MISSING"
   ;
   value V00081F 
      1 = "01-INBOARD ENGINE"
      2 = "02-OUTBOARD MOTOR"
      3 = "03-INBOARD-OUTBOARD ENGINE"
      88 = "88-INVALID RESPONSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED/MISSING"
   ;
   value V00083F 
      1 = "01-NEW"
      2 = "02-USED"
      88 = "88-INVALID RESPONSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED/MISSING"
   ;
   value V00090F 
      1 = "01-YES"
      2 = "02-NO"
      88 = "88-INVALID RESPONSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED/MISSING"
   ;
   value M00001F 
      1 = "01-YES"
      2 = "02-NO"
      88 = "88-INVALID RESPONSE"
      99 = "99-MISSING"
   ;
   value V00094F 
      1 = "01-VERY EXPERIENCED"
      2 = "02-SOMEWHAT EXPERIENCED"
      3 = "03-SOMEWHAT INEXPERIENCED"
      4 = "04-VERY INEXPERIENCED"
      88 = "88-INVALID RESPONSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED/MISSING"
   ;
   value V00095F 
      1 = "01-YES"
      2 = "02-NO"
      88 = "88-INVALID RESPONSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED/MISSING"
   ;
   value V00159F 
      1 = "01-GAVE RESPONSE"
      88 = "88-INVALID RESPONSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED/MISSING"
   ;
   value V00162F 
      1 = "01-GAVE RESPONSE"
      88 = "88-INVALID RESPONSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED/MISSING"
   ;
   value V00163F 
      1 = "01-GAVE RESPONSE"
      88 = "88-INVALID RESPONSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED/MISSING"
   ;
   value V00165F 
      1 = "01-GAVE RESPONSE"
      88 = "88-INVALID RESPONSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED/MISSING"
   ;
   value V00167F 
      1 = "01-GAVE RESPONSE"
      88 = "88-INVALID RESPONSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED/MISSING"
   ;
   value V00168F 
      1 = "01-GAVE RESPONSE"
      88 = "88-INVALID RESPONSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED/MISSING"
   ;
   value V00171F 
      1 = "01-GAVE RESPONSE"
      88 = "88-INVALID RESPONSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED/MISSING"
   ;
   value V00172F 
      1 = "01-GAVE RESPONSE"
      88 = "88-INVALID RESPONSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED/MISSING"
   ;
   value V00177F 
      1 = "01-GAVE RESPONSE"
      88 = "88-INVALID RESPONSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED/MISSING"
   ;
   value V00180F 
      1 = "01-GAVE RESPONSE"
      88 = "88-INVALID RESPONSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED/MISSING"
   ;
   value V00185F 
      1 = "01-YES"
      2 = "02-NO"
      88 = "88-INVALID RESPONSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED/MISSING"
   ;
   value PROCDF 
      1 = "1-PROCEED"
      2 = "2-END"
   ;
   value V00186F 
      1 = "01-HUMAN POWERED WITH OARS, PADDLES, OR PEDALS"
      2 = "02-AIR THRUST"
      3 = "03-PROPELLER"
      4 = "04-SAIL"
      5 = "05-WATER JET"
      88 = "88-INVALID RESPONSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED/MISSING"
   ;
   value V00187F 
      1 = "01-GAVE RESPONSE"
      88 = "88-INVALID RESPONSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED/MISSING"
   ;
   value V00190F 
      1 = "01-GAVE RESPONSE"
      88 = "88-INVALID RESPONSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED/MISSING"
   ;
   value V00191F 
      1 = "01-GAVE RESPONSE"
      88 = "88-INVALID RESPONSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED/MISSING"
   ;
   value V00192F 
      1 = "01-GAVE RESPONSE"
      88 = "88-INVALID RESPONSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED/MISSING"
   ;
   value RECF 
      1 = "01-BOAT 1"
      2 = "02-BOAT 2"
      3 = "03-BOAT 3"
      4 = "04-BOAT 4"
      5 = "05-I DO NOT OWN ANY OTHER BOATS"
      88 = "88-INVALID RESPONSE"
      99 = "99-MISSING"
   ;
   value V00204F 
      1 = "01-REGISTERED/YES"
      2 = "02-UNREGISTERED/NO"
      88 = "88-INVALID RESPONSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED/MISSING"
   ;
   value V00195F 
      1 = "01-ALABAMA"
      2 = "02-ALASKA"
      4 = "04-ARIZONA"
      5 = "05-ARKANSAS"
      6 = "06-CALIFORNIA"
      8 = "08-COLORADO"
      9 = "09-CONNECTICUT"
      10 = "10-DELAWARE"
      11 = "11-DC"
      12 = "12-FLORIDA"
      13 = "13-GEORGIA"
      15 = "15-HAWAII"
      16 = "16-IDAHO"
      17 = "17-ILLINOIS"
      18 = "18-INDIANA"
      19 = "19-IOWA"
      20 = "20-KANSAS"
      21 = "21-KENTUCKY"
      22 = "22-LOUISIANA"
      23 = "23-MAINE"
      24 = "24-MARYLAND"
      25 = "25-MASSACHUSETTS"
      26 = "26-MICHIGAN"
      27 = "27-MINNESOTA"
      28 = "28-MISSISSIPPI"
      29 = "29-MISSOURI"
      30 = "30-MONTANA"
      31 = "31-NEBRASKA"
      32 = "32-NEVADA"
      33 = "33-NEW HAMPSHIRE"
      34 = "34-NEW JERSEY"
      35 = "35-NEW MEXICO"
      36 = "36-NEW YORK"
      37 = "37-NORTH CAROLINA"
      38 = "38-NORTH DAKOTA"
      39 = "39-OHIO"
      40 = "40-OKLAHOMA"
      41 = "41-OREGON"
      42 = "42-PENNSYLVANIA"
      44 = "44-RHODE ISLAND"
      45 = "45-SOUTH CAROLINA"
      46 = "46-SOUTH DAKOTA"
      47 = "47-TENNESSEE"
      48 = "48-TEXAS"
      49 = "49-UTAH"
      50 = "50-VERMONT"
      51 = "51-VIRGINIA"
      53 = "53-WASHINGTON"
      54 = "54-WEST VIRGINA"
      55 = "55-WISCONSIN"
      56 = "56-WYOMING"
      72 = "72-PUERTO RICO"
      88 = "88-INVALID RESPONSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED/MISSING"
   ;
   value V00286F 
      1 = "01-YES"
      2 = "02-NO"
      88 = "88-INVALID RESPONSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED/MISSING"
   ;
   value V00288F 
      1 = "01-YES"
      2 = "02-NO"
      88 = "88-INVALID RESPONSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED/MISSING"
   ;
   value V00290F 
      1 = "01-ON THE WATER"
      2 = "02-ON LAND"
      88 = "88-INVALID RESPONSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED/MISSING"
   ;
   value V00299F 
      1 = "01-A ROWBOAT"
      2 = "02-AN INFLATABLE"
      3 = "03-NEITHER"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00308F 
      1 = "01-A CABIN MOTORBOAT"
      2 = "02-A JET BOAT"
      3 = "03-AN OPEN MOTORBOAT"
      4 = "04-A PONTOON BOAT"
      5 = "05-A HOUSEBOAT"
      6 = "06-AN AIRBOAT"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00317F 
      1 = "01-AN AUXILIARY MOTOR SAILBOAT"
      2 = "02-A SAIL-ONLY SAILBOAT"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00326F 
      1 = "01-YES"
      2 = "02-NO"
      88 = "88-INVALID RESPONSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED/MISSING"
   ;
   value V00379F 
      1 = "01-YES"
      2 = "02-NO"
      88 = "88-INVALID RESPONSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED/MISSING"
   ;
   value $MSUBOATSPECF 
      "01" = "01-CABIN MOTORBOAT"
      "02" = "02-JET BOAT"
      "03" = "03-OPEN MOTORBOAT"
      "04" = "04-PONTOON BOAT"
      "05" = "05-HOUSEBOAT"
      "06" = "06-AIR BOAT"
      "07" = "07-SOME POWER BOAT TYPE"
      "08" = "08-AUXILLARY MOTOR SAIL"
      "09" = "09-SAIL-ONLY SAILBOAT"
      "10" = "10-SOME SAILBOAT TYPE"
      "11" = "11-PWC, JET SKI"
      "12" = "12-CANOE"
      "13" = "13-KAYAK"
      "14" = "14-ROWBOAT"
      "15" = "15-INFLATABLE"
      "16" = "16-SOME OTHER BOAT TYPE"
      "88" = "88-INVALID RESPONSE"
      "97" = "97-DO NOT KNOW"
      "99" = "99-MISSING"
   ;
   value $BOATTYPF 
      "1A" = "1A-Power Boat <16ft"
      "1B" = "1B-Power Boat 16 - 20ft"
      "1C" = "1C-Power Boat 21 - 28ft"
      "1D" = "1D-Power Boat >28"
      "2A" = "2A-Sail < 26"
      "2B" = "2B-Sail >= 26"
      "3" = "3-PWC"
      "4" = "4-Canoe"
      "45" = "45-Self-propelled"
      "5" = "5-Kayak"
      "6A" = "6A-Pontoon"
      "6B" = "6B-Other"
      "6C" = "6C-Rowboat/inflatable"
   ;
   value $MSUVERIFYLENGTHF 
      "-" = "- -LENGTH WAS NOT PROVIDED"
      "L" = "Y-LENGTH PROVIDED WAS TOO LONG"
      "S" = "Y-LENGTH PROVIDED WAS TOO SHORT"
      "Y" = "Y-LENGTH PROVIDED VERIFIED PROPER"
   ;
	VALUE btypef  
		.='(.)All Types' 
		1='(1)Power boats'
		2='(2)Sail boats'  
		3='(3)PWCs'
		4='(4)Canoes' 
		5='(5)Kayaks'
		6='(6)Pontoons'  
		7='(7)Row/Inf'
	;
   value  regst_fmt
     1 = "AL"  
     2 = "AK"  
     4 = "AZ"  
     5 = "AR"  
     6 = "CA"  
     8 = "CO"  
     9 = "CT"  
    10 = "DE"  
    11 = "DC"  
    12 = "FL"  
    13 = "GA"  
    15 = "HI"  
    16 = "ID"  
    17 = "IL"  
    18 = "IN"  
    19 = "IA"  
    20 = "KS"  
    21 = "KY"  
    22 = "LA"  
    23 = "ME"  
    24 = "MD"  
    25 = "MA"  
    26 = "MI"  
    27 = "MN"  
    28 = "MS"  
    29 = "MO"  
    30 = "MT"  
    31 = "NE"  
    32 = "NV"  
    33 = "NH"  
    34 = "NJ"  
    35 = "NM"  
    36 = "NY"  
    37 = "NC"  
    38 = "ND"  
    39 = "OH"  
    40 = "OK"  
    41 = "OR"  
    42 = "PA"  
    44 = "RI"  
    45 = "SC"  
    46 = "SD"  
    47 = "TN"  
    48 = "TX"  
    49 = "UT"  
    50 = "VT"  
    51 = "VA"  
    53 = "WA"  
    54 = "WV"  
    55 = "WI"  
    56 = "WY"  
    72 = "PR"  
   ; 
   value $ region_fmt
      "AL" = "(3) South"
      "AK" = "(4) West"
      "AZ" = "(4) West"
      "AR" = "(3) South"
      "CA" = "(4) West"
      "CO" = "(4) West"
      "CT" = "(1) Northeast"
      "DE" = "(3) South"
      "DC" = "(3) South"
      "FL" = "(3) South"
      "GA" = "(3) South"
      "HI" = "(4) West"
      "ID" = "(4) West"
      "IL" = "(2) Midwest"
      "IN" = "(2) Midwest"
      "IA" = "(2) Midwest"
      "KS" = "(2) Midwest"
      "KY" = "(3) South"
      "LA" = "(3) South"
      "ME" = "(1) Northeast"
      "MD" = "(3) South"
      "MA" = "(1) Northeast"
      "MI" = "(2) Midwest"
      "MN" = "(2) Midwest"
      "MS" = "(3) South"
      "MO" = "(2) Midwest"
      "MT" = "(4) West"
      "NE" = "(2) Midwest"
      "NV" = "(4) West"
      "NH" = "(1) Northeast"
      "NJ" = "(1) Northeast"
      "NM" = "(4) West"
      "NY" = "(1) Northeast"
      "NC" = "(3) South"
      "ND" = "(2) Midwest"
      "OH" = "(2) Midwest"
      "OK" = "(3) South"
      "OR" = "(4) West"
      "PA" = "(1) Northeast"
      "RI" = "(1) Northeast"
      "SC" = "(3) South"
      "SD" = "(2) Midwest"
      "TN" = "(3) South"
      "TX" = "(3) South"
      "UT" = "(4) West"
      "VT" = "(1) Northeast"
      "VA" = "(3) South"
      "WA" = "(4) West"
      "WV" = "(3) South"
      "WI" = "(2) Midwest"
      "WY" = "(4) West"
      "PR" = "(9) Puerto Rico"
   ;
run;
